/* SQL DDL: Create an implementation of the model using the SQL Data Definition Language */
/*  Note: Comments such as this may not be supported by your system and may have to be removed */
/*  You may want to change some field types to improve the implementation on your DBMS. */
/*  Data type 'National Character' etc. indicates Unicode text. */
/*   PostgreSQL: You should create the entire database as Unicode!  */
/*   PostgreSQL: For Postgres you should create the entire database as Unicode! The 'National' has been removed from the SQL code */
/*   PostgreSQL: the data type CHARACTER VARYING has been replaced with VARCHAR */
/*   PostgreSQL: the data type DATETIME has been replaced with TIMESTAMP */
/*   PostgreSQL: Table and field names have been quoted (= "Fieldname") to allow case-sensitivity */
/*   PostgreSQL: the default values for boolean fields have been replaced with 'true' and 'false' */



/*=== Table: "Biota_S04_CHAR" ===*/
/* Descriptor project Biota_S04: Character table. */
  /*   CID: Character ID number. */
  /*   CharName: Short name of character. */
  /*   Unit: For numeric characters: an optional measurement unit like 'mm'. Only true units here, text like 'wide' belongs to CharWording2! */
  /*   Notes: Character notes. */
  /*   Type: Type of character: Text, Ordered/unordered multistate, Integer/Real numeric. */
  /*   Mandatory: Is the scoring of this character mandatory (required) in each item? */
  /*   MultiStateType: Are multiple states allowed and how are they interpreted? */
  /*   Reliability: Reliability (or weight) of character for identification, 1-10, default is 5. */
  /*   Availability: Availability (or accessibility) of character for identification, 1-10, default is 5. This is an extension to the Delta standard. */
  /*   Fuzziness: For identification: Unless a range is explicitly present, used to form a range around the mean (RN/IN) or state (OM). */
  /*   FuzzinessIsPercent: Interpret 'Fuzziness' as 'percent' rather than 'absolute value' (e.g. Fuzziness=10 -> range=mean +/- 10%, instead of +/- 10 absolute). */
  /*   KeyStates: For use in a key: combine multistate char, into new combinations or define ranges for numeric char. */
  /*   CharHeading: A heading defined in the headings definition, inserted in char. def. output in front of the current character. */
  /*   HeadingLink: A heading defined in the headings definition, inserted in natural language descriptions in front of descriptions using this character. */
  /*   CharWording: Natural language descript.: Wording to be used instead of CharName. */
  /*   CharWording2: Natural language descript.: Wording to be used AFTER states or values + unit, e.g. 'wide' for 'leaves 3-5 mm wide'. */
  /*   UnitIsPrefix: True if unit is to be placed in front of value, e.g. "pH 7.2". */
  /*   FormatString: Default formatting for all states (compare StateFormatString). Esp. for numeric values (number of decimal places etc.). Standard Basic formatting string like "#.0". */
  /*   ParagraphLink: Nat.language descript.: Define char. linked into a single paragraph. A new paragraph starts if group ID changes. */
  /*   SentenceLink: Nat.language descript.: Define char. linked into a single sentence. A new sentence starts if group ID changes or whenever Null. */
  /*   CommaLink: Nat.language descript.: Define characters linked into a comma-enumeration ('sub-sentence'). A new group starts starts if group ID changes or whenever Null. */
  /*   SpecialLink: Nat.language descript.: Define characters that are linked by special means (as defined in SpecialElement). */
  /*   SpecialElement: Nat.language descript.: SpecialLink is rendered using this ReportElement (concatenation: char. separated only by blank, multi-char. formula/equation or table definition) [Denormalized n:m relation b/w Char.SpecialLink & ReportElement.ReportElement] */
  /*   UseComma2: Nat.language descript.: Use alternative comma separator between states of this character (e.g. for Chinese). */
  /*   OmitFinalComma: Nat.language descript.: The final comma between character states is omitted ('1,2 and 3' instead of '1,2, and 3'). */
  /*   OmitValues: Natural language descript.: Omit lower ('-') or upper ('+') part of numeric character ranges. */
  /*   Emphasize: Nat.language descript.: Emphasize (italic or bold print) this character in all items. */
  /*   OmitPeriod: Nat.language descript.: Omit the end delimiter (usually the period for a sentence, DELTA: 'OMIT PERIOD FOR CHAR'). */
  /*   NumStates: Number of states for this character, default is 2. Calculated automatically, do not edit! */
CREATE TABLE "BIOTA_S04_CHAR" (
    "CID" 	int2	 NOT NULL PRIMARY KEY,
    "CharName" 	varchar(255)	 NOT NULL UNIQUE,
    "Unit" 	varchar(255)	 NULL,
    "Notes" 	text	 NULL,
    "Type" 	varchar(2)	 NOT NULL DEFAULT 'UM',
    "Mandatory" 	bool	 NOT NULL DEFAULT 'false',
    "MultiStateType" 	int2	 NOT NULL DEFAULT 1,
    "Reliability" 	float4	 NOT NULL DEFAULT 5,
    "Availability" 	float4	 NOT NULL DEFAULT 5,
    "Fuzziness" 	float4	 NOT NULL DEFAULT 0,
    "FuzzinessIsPercent" 	bool	 NOT NULL DEFAULT 'false',
    "KeyStates" 	varchar(255)	 NULL,
    "CharHeading" 	int2	 NULL,
    "HeadingLink" 	int2	 NULL,
    "CharWording" 	varchar(255)	 NULL,
    "CharWording2" 	varchar(255)	 NULL,
    "UnitIsPrefix" 	bool	 NULL,
    "FormatString" 	varchar(255)	 NULL,
    "ParagraphLink" 	int4	 NULL DEFAULT 1,
    "SentenceLink" 	int4	 NULL,
    "CommaLink" 	int4	 NULL,
    "SpecialLink" 	int4	 NULL,
    "SpecialElement" 	int4	 NULL,
    "UseComma2" 	bool	 NULL,
    "OmitFinalComma" 	bool	 NOT NULL DEFAULT 'false',
    "OmitValues" 	varchar(1)	 NULL,
    "Emphasize" 	bool	 NULL DEFAULT 'false',
    "OmitPeriod" 	bool	 NULL DEFAULT 'false',
    "NumStates" 	int2	 NOT NULL DEFAULT 2
);




/*=== Table: "Biota_S04_CHAR_Heading" ===*/
/* Descriptor project Biota_S04: Character heading/Identification/HeadingLink table. */
  /*   HID: Character heading ID; determines sequence of headings when used in identification; change number to change that sequence! */
  /*   HeadingName: Heading name, used for CharHeadings and Named character groups (identification). */
  /*   HeadingWording: Optional wording; preferred over HeadingName as HeadingLink in natural language output. */
  /*   Notes: Internal notes (not exported to Delta format). */
  /*   AutoGroup: Empty for user defined headings; else special code which is recognized during identification or a SQL queryreturning a set of character IDs. (HeadingName of predefined AutoGroups may be changed!). */
CREATE TABLE "BIOTA_S04_CHAR_Heading" (
    "HID" 	int2	 NOT NULL PRIMARY KEY,
    "HeadingName" 	varchar(255)	 NOT NULL UNIQUE,
    "HeadingWording" 	varchar(255)	 NULL,
    "Notes" 	text	 NULL,
    "AutoGroup" 	varchar(255)	 NULL
);




/*=== Table: "Biota_S04_CHAR_Heading_Link" ===*/
/* Descriptor project Biota_S04: Character groups for Identification, Linking. */
  /*   HID: Character heading ID to be linked. */
  /*   CID: Character ID to which the identification heading is applicable. */
CREATE TABLE "BIOTA_S04_CHAR_Heading_Link" (
    "HID" 	int2	 NOT NULL,
    "CID" 	int2	 NOT NULL,
  PRIMARY KEY ("HID","CID")
);




/*=== Table: "Biota_S04_CS" ===*/
/* Descriptor project Biota_S04: Character states for each character. */
  /*   CID: Character ID. */
  /*   CS: Character state code. Usually pos. integer number or special codes for variable/unknown and for statistics (mean etc.). */
  /*   CharStateName: Name or description of character state. */
  /*   Notes: Character state notes. */
  /*   StateWording: Wording to be used instead of CharStateName for natural language descriptions output. */
  /*   StateFormatString: State specific formatting, overriding FormatString defined in the character definition. Standard Basic formatting string like "#.0". */
  /*   Implicit: Mark this state as a default which is automatically set. */
  /*   UseEdit: Use this state during entering or updating of item descriptions. */
  /*   UseIdentify: Use this state during interactive identification. */
  /*   UseDescr: Use this state for natural language item descriptions. */
  /*   UsePhylo: Use this state for phylogenetic analysis. */
  /*   UseOther: Use this to define a character state set for user-defined purposes. */
  /*   MinValue: Numeric characters only: The lowest value of X in item description to be mapped to this state (inclusive). */
  /*   MaxValue: Numeric characters only: The highest value of X in item description to be mapped to this state (inclusive). */
CREATE TABLE "BIOTA_S04_CS" (
    "CID" 	int2	 NOT NULL,
    "CS" 	varchar(16)	 NOT NULL,
-- ???    "CharStateName" 	varchar(255)	 NOT NULL UNIQUE,
    "CharStateName" 	varchar(255)	 NOT NULL,
    "Notes" 	text	 NULL,
    "StateWording" 	varchar(255)	 NULL,
    "StateFormatString" 	varchar(255)	 NULL,
    "Implicit" 	bool	 NOT NULL DEFAULT 'false',
    "UseEdit" 	bool	 NULL DEFAULT 'true',
    "UseIdentify" 	bool	 NULL DEFAULT 'false',
    "UseDescr" 	bool	 NULL DEFAULT 'false',
    "UsePhylo" 	bool	 NULL DEFAULT 'false',
    "UseOther" 	bool	 NULL DEFAULT 'false',
    "MinValue" 	float8	 NOT NULL DEFAULT -1E+308,
    "MaxValue" 	float8	 NOT NULL DEFAULT 1E+308,
  PRIMARY KEY ("CID","CS")
);




/*=== Table: "Biota_S04_DEP" ===*/
/* Descriptor project Biota_S04: Dependent (= inapplicable) characters for each character state. */
  /*   CID: Controlling character ID. */
  /*   CS: Controlling character state. */
  /*   InapplicableCID: CID of dependent character, i.e. inapplicable for any item where current CID/CS combination is used. */
CREATE TABLE "BIOTA_S04_DEP" (
    "CID" 	int2	 NOT NULL,
    "CS" 	varchar(16)	 NOT NULL,
    "InapplicableCID" 	int2	 NOT NULL,
  PRIMARY KEY ("CID","CS","InapplicableCID")
);




/*=== Table: "Biota_S04_DESCR" ===*/
/* Descriptor project Biota_S04: Data/descriptions for each item. */
  /*   IID: Item ID. */
  /*   CID: Character ID. */
  /*   Modifier: Modifier wording for categorical or numerical data, e.g. "mostly", "usually", "rarely". */
  /*   CS: Character state code. Usually pos. integer number or special codes for variable/unknown and for statistics (mean etc.). */
  /*   X: Numeric value, defined by CS. */
  /*   TXT: Text data. */
  /*   Notes: Notes and additional information, included in natural language item descriptions. */
  /*   SEQ: Sequence of character states for the item. */
CREATE TABLE "BIOTA_S04_DESCR" (
    "IID" 	int4	 NOT NULL,
    "CID" 	int2	 NOT NULL,
    "Modifier" 	varchar(255)	 NULL,
    "CS" 	varchar(16)	 NOT NULL,
    "X" 	float8	 NULL,
    "TXT" 	text	 NULL,
    "Notes" 	text	 NULL,
    "SEQ" 	int4	 NULL,
  PRIMARY KEY ("CID","CS","IID")
);




/*=== Table: "Biota_S04_ITEM" ===*/
/* Descriptor project Biota_S04: Item or taxon table. */
  /*   IID: Item ID. */
  /*   ItemName: Name or description of item (incl. taxon authors if necessary), link to taxonomic subsystem. */
  /*   ItemWording: Natural language descript.: Wording to be used instead of ItemName. */
  /*   Notes: Item notes. */
  /*   Abundance: Abundance, relative importance (or weight) of item, 1-10, default is 5. */
  /*   CollUnit: Unit code in specimen collection, link into collection subsystem. NOT DEFINED IN DELTA! */
  /*   LitRef: Literature reference (user-readable text form). NOT DEFINED IN DELTA! */
  /*   LitKey: Literature reference (numeric link into literature reference subsystem). NOT DEFINED IN DELTA! */
  /*   LitRefDetail: Reference detail, like page(s) of interest, specific figures, etc. */
CREATE TABLE "BIOTA_S04_ITEM" (
    "IID" 	int4	 NOT NULL PRIMARY KEY,
    "ItemName" 	varchar(255)	 NOT NULL,
    "ItemWording" 	varchar(255)	 NULL,
    "Notes" 	text	 NULL,
    "Abundance" 	float4	 NOT NULL DEFAULT 5,
    "CollUnit" 	varchar(255)	 NULL,
    "LitRef" 	varchar(255)	 NULL,
    "LitKey" 	int4	 NULL,
    "LitRefDetail" 	varchar(255)	 NULL
);




/*=== Table: "Biota_S04_MOD" ===*/
/* Descriptor project Biota_S04: Modifier wordings for categorical or numerical data. */
  /*   Usage: Type of characters for which the modifier is applicable, e.g. GENERAL. COLORS, FREQuency of occurrence. */
  /*   Modifier: Modifier wording for categorical or numerical data, e.g. "mostly", "usually", "rarely". */
  /*   Reliability: Influence of modifier on data coded through categorical/numerical char. states. More (>5) or less reliable (<5); 5 is default. */
  /*   MisinterpretationMarker: If set to true, the state to which this modifier is added is marked as being present only by misinterpretation of structure (phyllocladium as leaf) or state (rough spore surface as smooth). */
  /*   Postfix: Checked = output after the character state wording, unchecked = in front of it. */
  /*   UseBlank: Checked = blank is added between the modifier wording and the item data text, else modifier added compress. */
  /*   Operator: >0 = Override operator, the normal operator between states is omitted when this modifier is encountered, e.g. to insert AND where normal operator would be OR. */
  /*   Notes: Internal notes. */
  /*   LowerFreq: The lower border of the frequency range, for freq. modifiers only. */
  /*   UpperFreq: The upper border of the frequency range, for freq. modifiers only. */
CREATE TABLE "BIOTA_S04_MOD" (
    "Usage" 	varchar(255)	 NOT NULL,
    "Modifier" 	varchar(255)	 NOT NULL PRIMARY KEY,
    "Reliability" 	int2	 NOT NULL DEFAULT 5,
    "MisinterpretationMarker" 	bool	 NOT NULL DEFAULT 'false',
    "Postfix" 	bool	 NOT NULL,
    "UseBlank" 	bool	 NOT NULL DEFAULT 'true',
    "Operator" 	int2	 NOT NULL DEFAULT 0,
    "Notes" 	varchar(255)	 NULL,
    "LowerFreq" 	float4	 NULL,
    "UpperFreq" 	float4	 NULL
);




/*=== Table: "Biota_S04_MOD_Link" ===*/
/* Descriptor project Biota_S04: Links between characters and modifiers. */
  /*   CID: Character ID to which the modifier is applicable. */
  /*   Modifier: Modifier wording for categorical or numerical data, e.g. "mostly", "usually", "rarely". */
CREATE TABLE "BIOTA_S04_MOD_Link" (
    "CID" 	int2	 NOT NULL,
    "Modifier" 	varchar(255)	 NOT NULL,
  PRIMARY KEY ("Modifier","CID")
);




/*=== Table: "Biota_S04_PROPERTY" ===*/
/* Descriptor project Biota_S04: General header information about the project. */
  /*   PropertyName: The name of the project property (do not change!). */
  /*   TextValue: Text information. Use Shift F2 to zoom into larger window! */
  /*   DateTimeValue: Date or time information, e.g. of last update. */
  /*   NumericValue: Numerical information, stored as real number. */
CREATE TABLE "BIOTA_S04_PROPERTY" (
    "PropertyName" 	varchar(255)	 NOT NULL PRIMARY KEY,
    "TextValue" 	text	 NULL,
    "DateTimeValue" 	timestamp	 NULL,
    "NumericValue" 	float8	 NULL
);




/*=== Table: "Biota_S04_ReportElement" ===*/
/* Descriptor project Biota_S04: ReportElements for natural language description formulas, tables, etc. */
  /*   ReportElement: ID of report element (1-10 are reserved!). */
  /*   Language: Language to which the ReportElement is applicable. */
  /*   Description: Text that describes the use of the report element (shown in user interface). */
  /*   ParagraphBefore: Start a new paragraph before the ReportElement. */
  /*   TextBefore: Text inserted before the ReportElement (unformatted text). */
  /*   TextBetween: Enumeration separator between multiple subelements (e.g. characters); used only if ComplexWording is empty! */
  /*   TextAfter: Text inserted after the ReportElement (unformatted text). */
  /*   ParagraphAfter: Start a new paragraph after the ReportElement. */
  /*   ComplexWording: Wording for multiple characters, char. are inserted at |1, |2, etc.; |U = Unit, |C new table column, |R new table row. */
  /*   ComplexWordingFormat: 0 = RTF; 1 = HTML; 2= unformatted, will be reformatted with character format. */
  /*   UseWordingIfIncomplete: Yes: char. missing in an item are replaced by ''; No: AlternativeElement is tried, if none fitting found: EnumSeparator is used. */
  /*   AlternativeElement: Another ReportElement that is used if not all elements in ComplexWording are present, see 'UseWordingIfIncomplete'. */
  /*   CapitalizeStart: Capitalize first letter at start of this group. */
  /*   CapitalizeWithin: Capitalize first letter of each element (each char. in enumeration or table cell). */
  /*   WordgTruncation: Wording truncation (e.g. char. wording). 0=disable, 1=enable, restart, 2=enable, continue. */
  /*   RepElementNotes: Internal development notes. */
CREATE TABLE "BIOTA_S04_ReportElement" (
    "ReportElement" 	int4	 NOT NULL,
    "Language" 	varchar(2)	 NOT NULL,
    "Description" 	varchar(255)	 NULL,
    "ParagraphBefore" 	bool	 NULL,
    "TextBefore" 	varchar(255)	 NULL,
    "TextBetween" 	varchar(255)	 NULL,
    "TextAfter" 	varchar(255)	 NULL,
    "ParagraphAfter" 	bool	 NULL,
    "ComplexWording" 	varchar(255)	 NULL,
    "ComplexWordingFormat" 	int2	 NULL DEFAULT 2,
    "UseWordingIfIncomplete" 	bool	 NULL,
    "AlternativeElement" 	int4	 NULL,
    "CapitalizeStart" 	bool	 NULL DEFAULT 'false',
    "CapitalizeWithin" 	bool	 NULL DEFAULT 'false',
    "WordgTruncation" 	int2	 NOT NULL DEFAULT 0,
    "RepElementNotes" 	text	 NULL,
  PRIMARY KEY ("ReportElement","Language")
);




/*=== Table: "BIOTA_S04_RSC" ===*/
/* Descriptor project BIOTA_S04: External resources stored as files or URL, e.g. illustrations for characters/items. */
  /*   IID: ID of associated item (optional). */
  /*   CID: ID of associated character (optional). */
  /*   CS: ID of associated character state (set to U or TE for text characters if resource belongs to char. in general). */
  /*   Resource: Filename of illustration (photo/drawing/graph) or other media resources. See _HEADING properties MediaDefaultPath/MediaDefaultURL to set global paths. */
  /*   Caption: Caption for the resource, e.g. a text to display while showing an illustration or a video. */
  /*   Notes: Internal notes (perhaps also formatting commands for INTKEY). */
  /*   ItemDefault: This image is a default image for the whole item, regardless of character association. */
  /*   CharDefault: This image is a default image for the whole character, regardless of character state association. */
  /*   RID: Media resource ID (necessary, because either IID or CID may be missing). */
  /*   ItemDescription: Include the resource, esp. images in the natural language description of items. */
  /*   CharDefinition: Include the resource, esp. images in character definition report. */
CREATE TABLE "BIOTA_S04_RSC" (
    "IID" 	int4	 NULL,
    "CID" 	int2	 NULL,
    "CS" 	varchar(16)	 NULL DEFAULT 'U',
    "Resource" 	varchar(255)	 NULL,
    "Caption" 	text	 NULL,
    "Notes" 	text	 NULL,
    "ItemDefault" 	bool	 NOT NULL DEFAULT 'false',
    "CharDefault" 	bool	 NOT NULL DEFAULT 'false',
    "RID" 	SERIAL  	 NOT NULL PRIMARY KEY,
    "ItemDescription" 	bool	 NULL DEFAULT 'false',
    "CharDefinition" 	bool	 NULL DEFAULT 'false'
);


