#!/bin/sh
#################################################################
# Transfer using  Secure SHELL and SSH agent
# Dieter Neubacher
# 10.03.2004
#################################################################
user="Administrator"
# user="didi"
#
# debug = yes/no
#
debug="no"
##################################################################
#                     Functions                                  #
##################################################################
### Copy files between hosts
copy_files()
{
 if [ $files_file != "files_empty.txt" ];then
  cat $files_file | grep -v "#" | while read -r line
  do
   direction=`echo ${line} | cut -d " " -f 1`
   file1=`echo ${line}     | cut -d " " -f 2`
   file2=`echo ${line}     | cut -d " " -f 3`

   case ${direction} in
      "l2r") :	### From localhost to remote host
	  echo "From localhost to remote host"
          echo "$file1  --> ${user}@${host}:${file2}"
	  echo ""
	  if [ $debug == "yes" ];
	  then
	    echo scp $file1 ${user}@${host}:${file2};
	  else
	    scp $file1 ${user}@${host}:${file2};
	  fi
      ;;
      "r2l") :	### From remote host to localhost
          echo "From remote host to localhost"
          echo ${user}@"${host}:${file1}  --> localhost:${file2}"
	  echo ""
	  if [ $debug == "yes" ];
	  then
	    echo scp ${user}@${host}:${file1} ${file2};
	  else
	    scp ${user}@${host}:${file1} ${file2};
	  fi
      ;;
      *)
          echo "Unknown direction of copy : ${direction}"
          echo "Must be either local or remote."
      ;;
   esac
  done
 fi
}
##########################################
### Execute commands on remote hosts
##########################################
execute_remote_commands()
{
 if [ $remote_commands_file != "commands_empty.txt" ];then
  cat $remote_commands_file | grep -v "#" |  while read -r line
  do
   command_str="${line}"
   echo "Executing remote $command_str ..."
   if [ $debug == "yes" ];
   then
      echo "ssh -x -a ${user}@${host}  ${command_str} &"      
   else
      ssh -x -a ${user}@${host}  ${command_str} &      
   fi
   wait $!
   echo "Execute remote $command_str OK."
  done
 fi
}
###########################################
### Execute commands on local hosts
###########################################
execute_local_commands()
{
 if [ $local_commands_file != "commands_empty.txt" ];then
  cat $local_commands_file | grep -v "#" |  while read -r line
  do
   command_str="${line}"
   echo "Executing local $command_str ..."
   ### ssh -x -a ${user}@${host}  ${command_str} &
   if [ $debug == "yes" ];
   then
      echo  "${command_str} &"      
   else
      ${command_str} &
   fi
   wait $!
   echo "Execute local $command_str OK."
  done
 fi
}

### Wrapper function to execute_commands and copy_files functions
doit()
{
 cat $host_file | grep -v "#" | while read -r host
 do
  echo "host=$host processing..."
  case "${mode}" in
	"1")
		copy_files
		execute_local_commands
		;;
	"2")
		execute_local_commands
		copy_files
		;;
	"3")
		execute_remote_commands
		copy_files
		execute_local_commands
		;;
	*)
		echo "$0 : Unknown mode : ${mode}"
		;;
  esac
  echo "host=$host ok."
  echo "------------------------------------------------------------------"
 done
}

##################################################################
### Program starts here
##################################################################

if [ $# -ne 5 ]; then
 echo "Usage : $0 mode host_file files_file remote_commands_file local_commands_file"
 echo ""
 echo "mode is 1 or 2 "
 echo "    1 : first copy files and then execute commands."
 echo "    2 : first execute commands and then copy files."
 echo "    3 : first execute remote-commands, then copy files and then execute local-commands."
 echo ""
 echo "If the name of files.txt is files_empty.txt then it is not processed."
 echo "If the name of remote_commands.txt is remote_commands_empty.txt then it is"
 echo "If the name of local_commands.txt is local_commands_empty.txt then it is"
 echo "not processed."
 exit
fi


mode=$1
host_file=$2
files_file=$3
remote_commands_file=$4
local_commands_file=$5

agent_info_file=~/.ssh/agent_info
if [ -f $agent_info_file ]; then
 . $agent_info_file
fi

if [ ! -f $host_file ]; then
 echo "Hosts file : $host_file does not exist!"
 exit 1
fi

if [ $files_file != "files_empty.txt" -a ! -f $files_file ]; then
  echo  "Files file : $files_file does not exist!"
  exit 1
fi

if [ $remote_commands_file != "commands_empty.txt" -a ! -f $remote_commands_file ]; then
 echo  "Commands file : $commands_file does not exist!"
 exit 1
fi

if [ $local_commands_file != "commands_empty.txt" -a ! -f $local_commands_file ]; then
 echo  "Commands file : $commands_file does not exist!"
 exit 1
fi

#### Do everything there
doit

