/* SQL DDL: Create an implementation of the model using the SQL Data Definition Language */
/*  Note: You may want to change some field types to improve the implementation on your DBMS */
/*   Comments such as this may not be supported by your system and may have to be removed *//*   PostgreSQL: You should create the entire database as Unicode!  */



/*=== Table: ExsEditor ===*/
/*  */
  /*   Name: Enter as Lastname Komma Firstnames, use blanks after comma and period. */
  /*   Exs_ID: Foreign Key, reference to Exs_ID in table Exsiccata. */
  /*   Sequence: (automatically set during entry, to maintain the sequence of editors). */
CREATE TABLE "ExsEditor"
 ( 
    "Name"  	 varchar( 255 )     	 NOT NULL,
    "Exs_ID"  	 int4              	 NOT NULL,
    "Sequence"   timestamp         	 NULL DEFAULT Now(),
  PRIMARY KEY ( "Name","Exs_ID" )
 );




/*=== Table: Exsiccata ===*/
/*  */
  /*   Exs_ID: ID of the exsiccatum. */
  /*   ExsAbbrev: Std. abbreviation (authors/editors, std. abbrev. of title). */
  /*   ExsTitle: Exact title (enter new entry if title spelling changed consistently). */
  /*   ExsEditInstitution: Issuing/Eding institution (If no editors are known, at least this must be entered). */
  /*   ExsEditLocation: City/Country where the exs. has been issued. */
  /*   PrecededBy: An earlier exsiccata publication appeared under different title or editors (Reference to entry in this database). */
  /*   SupersededBy: A later exsiccata publication appeared under different title or editors (Reference to entry in this database). */
  /*   ExsNumberFirst: If known: number of the first exs. that was issued by the current editors under the current title. */
  /*   ExsNumberLast: If known: number of the last exs. that was issued by the current editors under the current title. */
  /*   ExsPublYrFirst: If known: publication year of the first exs. that was issued by the current editors under the current title. */
  /*   ExsPublYrLast: If known: publication year of the last exs. that was issued by the current editors under the current title. */
  /*   Notes: Annotation, please add your name and a date for each annotation. */
  /*   Problems: Please explain here if you have a problem, this field will later be checked. */
  /*   Fungi: check if exsiccatum covers fungal species (default) 1 or -1= Yes it does, 0=No it does not, Null/empty = don't know. */
  /*   Algae: check if exsiccatum covers Algae/Cyanophyta. */
  /*   Mosses: check if exsiccatum covers mosses/bryophytes. */
  /*   Ferns: check if exsiccatum covers ferns. */
  /*   HigherPlants: check if exsiccatum covers higher plants. */
  /*   ExampleMNum: 1st Example in M deposited under: title of example issue. */
  /*   ExampleMDep: 1st Example in M deposited under (scientific name). */
  /*   ExampleMNum2: 2nd Example in M deposited under: title of example issue. */
  /*   ExampleMDep2: 2nd Example in M deposited under (scientific name). */
  /*   ExampleMNum3: 3rd Example in M deposited under: title of example issue. */
  /*   ExampleMDep3: 3rd Example in M deposited under (scientific name)  //Note: degenerated data model was introduced on purpose to keep database as simple as possible! */
  /*   InPfister85: included in Pfister 1985. */
  /*   InSayre69: included in Sayre 1969. */
CREATE TABLE "Exsiccata"
 ( 
    "Exs_ID" SERIAL   NOT NULL PRIMARY KEY,
    "ExsAbbrev"  	 varchar( 255 )     	 NOT NULL,
    "ExsTitle"  	 varchar( 255 )     	 NOT NULL,
    "ExsEditInstitution"  	 varchar( 255 )     	 NULL,
    "ExsEditLocation"  	 varchar( 255 )     	 NULL,
    "PrecededBy"  	 int4              	 NULL,
    "SupersededBy"  	 int4              	 NULL,
    "ExsNumberFirst"  	 varchar( 50 )     	 NULL,
    "ExsNumberLast"  	 varchar( 50 )     	 NULL,
    "ExsPublYrFirst"  	 varchar( 50 )     	 NULL,
    "ExsPublYrLast"  	 varchar( 50 )     	 NULL,
    "Notes"  	 varchar( 255 )     	 NULL,
    "Problems"  	 varchar( 255 )     	 NULL,
    "Fungi"  	 int2              	 NULL DEFAULT -1,
    "Algae"  	 int2              	 NULL DEFAULT Null,
    "Mosses"  	 int2              	 NULL DEFAULT Null,
    "Ferns"  	 int2              	 NULL DEFAULT Null,
    "HigherPlants"  	 int2              	 NULL DEFAULT Null,
    "ExampleMNum"  	 varchar( 255 )     	 NULL,
    "ExampleMDep"  	 varchar( 255 )     	 NULL,
    "ExampleMNum2"  	 varchar( 255 )     	 NULL,
    "ExampleMDep2"  	 varchar( 255 )     	 NULL,
    "ExampleMNum3"  	 varchar( 255 )     	 NULL,
    "ExampleMDep3"  	 varchar( 255 )     	 NULL,
    "InPfister85"  	 int2              	 NULL DEFAULT Null,
    "InSayre69"  	 int2              	 NULL DEFAULT Null
 );


ALTER TABLE "ExsEditor" ADD 
  FOREIGN KEY ( "Exs_ID" ) REFERENCES "Exsiccata" ( "Exs_ID" ) ON UPDATE CASCADE ON DELETE CASCADE
;