#!/bin/sh
# script_world05.sh
# Author: 2003, Volkmar Klatt, CanisMaior@web.de
################################################################
# This little shell script is not a standalone program, but get its
# information from program mapdispatcher and  draws a map of the world. 
################################################################
echo "Start script: "
#
# Params: MapFileName [ location ] [ location ] ...
# 
# !!! MapFileName is a filename without extention !!!
#
DEBUG=ON
#
# set MapFileName without extention 
#
MAP_FILE_NAME_WITHOUT_EXTENTION="$1"
EMPTY_MAP_FILE_NAME="$USER-grass-empty-map"
#
# set up logging filename
#
LOG_OUT="/tmp/$MAP_FILE_NAME_WITHOUT_EXTENTION.log"
#
if [ DEBUG ]
then
    echo "MapFile: $MAP_FILE_NAME_WITHOUT_EXTENTION" 
    echo "Locations: $2"
fi
#
#
# Setup WEB-Directory
#
case $HOSTNAME
    # Botanische Staatssammung Muenchen Produktions-Server
    in 
    ( "BSM1" )
	WEB_DIRECTORY="/data/wwwroot/DiversityNavigator/grass-gis-maps"
    ;;
    # Botanische Staatssammung Muenchen Aplication-Server
    ( "BSM2" )
	WEB_DIRECTORY="/data/wwwroot/DiversityNavigator/grass-gis-maps"
    ;;
    # Botanische Staatssammung Muenchen Test-Server
    ( "BSM2" )
	WEB_DIRECTORY="/data/wwwroot/DiversityNavigator/grass-gis-maps"
    ;;
    # didi's Test server
    ( "hongkong" )
	WEB_DIRECTORY="/srv/www/htdocs/grass-gis-maps"
    ;;
    # If no server is defined
    ( * ) 
	echo "Pleace setup the WEB_DIRECTORY for you server"
	exit 1
    ;;
esac
#
if [ DEBUG ]
then 
    echo "WebDirectory is set to: $WEB_DIRECTORY" 
fi
#
#
echo "MAPSET: map"                >> $HOME/.grassrc5
echo "LOCATION_NAME: worldmap"    >> $HOME/.grassrc5
echo "DIGITIZER: none"            >> $HOME/.grassrc5
echo "GISDBASE: $HOME/grass"      >> $HOME/.grassrc5 
#
DIGITIZER=none
GISBASE=/usr/local/grass5
GISDBASE=$HOME/grass
GISRC=$HOME/.grassrc5
LOCATION=$HOME/grass/worldmap/map
PATH=$PATH:/usr/local/grass5/bin:/usr/local/grass5/scripts
#
export DIGITIZER GISBASE GISDBASE GISRC LOCATION PATH
################################################################
# dimension
export GRASS_WIDTH=800
export GRASS_HEIGHT=400
#
echo "Start ..." > $LOG_OUT
echo "HOME: $HOME"    >> $LOG_OUT 2>> $LOG_OUT
echo user: `whoami`   >> $LOG_OUT 2>> $LOG_OUT
echo pwd:  `pwd`      >> $LOG_OUT 2>> $LOG_OUT
echo "MapFile: $MAP_FILE_NAME_WITHOUT_EXTENTION" >> $LOG_OUT
echo "Locations: $2" >> $LOG_OUT
#
# if not avalible create empty world map
#
# if [ ! -e "$WEB_DIRECTORY/$USER-grass-empty-map.gif" ]
if [ ! -e "$WEB_DIRECTORY/$USER-grass-empty-map.png" ]
then
    echo "create empty world map: $WEB_DIRECTORY/$USER-grass-empty-map.gif"
    echo "create empty world map: $WEB_DIRECTORY/$USER-grass-empty-map.gif" >> $LOG_OUT
    g.remove rast=D_cell >> $LOG_OUT 2>> $LOG_OUT
    g.region -g raster=landmass.rast >> $LOG_OUT 2>> $LOG_OUT
    d.mon start=CELL >> $LOG_OUT 2>> $LOG_OUT  
    d.rast -i map=landmass.rast bg=aqua     >> $LOG_OUT 2>> $LOG_OUT  
    d.vect worldmap_inkl_florida_res0.1.v color=black
    d.rast -o map=worldmap.rast catlist= >> $LOG_OUT 2>> $LOG_OUT
    d.mon stop=CELL  &> /dev/null
    d.mon select=CELL  &> /dev/null
    g.region  -g raster=D_cell >> $LOG_OUT 2>> $LOG_OUT
    r.out.png -q input=D_cell output=/tmp/$USER-grass-empty-map.png  >> $LOG_OUT 2>> $LOG_OUT
    pngtopnm /tmp/$EMPTY_MAP_FILE_NAME.png | ppmtogif > /tmp/$EMPTY_MAP_FILE_NAME.gif 2>>$LOG_OUT
#
#    cp /tmp/$EMPTY_MAP_FILE_NAME.gif $WEB_DIRECTORY/.
    cp /tmp/$EMPTY_MAP_FILE_NAME.png $WEB_DIRECTORY/.
    rm /tmp/$EMPTY_MAP_FILE_NAME.png
fi
#
# Build map for locations
#
#echo "raster ..." >> $LOG_OUT
echo "g.remove rast=D_cell" >>$LOG_OUT
g.remove rast=D_cell >> $LOG_OUT 2>> $LOG_OUT
#
echo "g.region -g raster=landmass.rast" >>$LOG_OUT
g.region -g raster=landmass.rast >> $LOG_OUT 2>> $LOG_OUT
#
echo "d.mon start=CELL" >> $LOG_OUT 
d.mon start=CELL >> $LOG_OUT 2>> $LOG_OUT  
#
# print map:
#
echo "print map ..." >> $LOG_OUT 2>> $LOG_OUT 
echo "d.rast -i map=landmass.rast bg=aqua" >> $LOG_OUT
d.rast -i map=landmass.rast bg=aqua     >> $LOG_OUT 2>> $LOG_OUT  
#
# border
#
echo "d.vect worldmap_inkl_florida_res0.1.v color=black" >> $LOG_OUT 2>> $LOG_OUT
d.vect worldmap_inkl_florida_res0.1.v color=black
#
echo "d.rast -o map=worldmap.rast catlist=$2" >> $LOG_OUT
d.rast -o map=worldmap.rast catlist=$2  >> $LOG_OUT 2>> $LOG_OUT
#
echo "d.mon stop=CELL"  >> $LOG_OUT
d.mon stop=CELL  >> $LOG_OUT 2>> $LOG_OUT 
#
#  export as png picture
#
#
echo "export map ..." >>$LOG_OUT 2>> $LOG_OUT
echo "d.mon select=CELL"  >> $LOG_OUT
d.mon select=CELL  >> $LOG_OUT 2>> $LOG_OUT 
echo "g.region  -g raster=D_cell" >> $LOG_OUT
g.region  -g raster=D_cell >> $LOG_OUT 2>> $LOG_OUT
#
echo "r.out.png -q input=D_cell output=/tmp/$MAP_FILE_NAME_WITHOUT_EXTENTION.png"  >> $LOG_OUT
r.out.png -q input=D_cell output=/tmp/$MAP_FILE_NAME_WITHOUT_EXTENTION.png  >> $LOG_OUT 2>> $LOG_OUT
#
# convert map to jpg-format
#
# pngtopnm /tmp/$MAP_FILE_NAME_WITHOUT_EXTENTION.png | ppmtojpeg > /tmp/$MAP_FILE_NAME_WITHOUT_EXTENTION.jpg 2>>$LOG_OUT
#
# convert map to gif-format
#
if [ DEBUG ] 
then
    echo "convert map to gif-format"
    echo "pngtopnm /tmp/$MAP_FILE_NAME_WITHOUT_EXTENTION.png | ppmtogif > /tmp/$MAP_FILE_NAME_WITHOUT_EXTENTION.gif" 
fi
#
# GIF
#
# pngtopnm /tmp/$MAP_FILE_NAME_WITHOUT_EXTENTION.png | ppmtogif > /tmp/$MAP_FILE_NAME_WITHOUT_EXTENTION.gif 2>>$LOG_OUT
#
# Copy map to the web-directory
#
if [ DEBUG ] 
then
    echo "Copy map to the web-directory"
#    echo "cp /tmp/$MAP_FILE_NAME_WITHOUT_EXTENTION.gif $WEB_DIRECTORY/." 
    echo "cp /tmp/$MAP_FILE_NAME_WITHOUT_EXTENTION.png $WEB_DIRECTORY/." 
fi
#
echo "Copy map to the web-directory" >>$LOG_OUT
#echo "cp /tmp/$MAP_FILE_NAME_WITHOUT_EXTENTION.gif $WEB_DIRECTORY/." >>$LOG_OUT
#cp "/tmp/$MAP_FILE_NAME_WITHOUT_EXTENTION.gif" "$WEB_DIRECTORY/." >>$LOG_OUT 2>>$LOG_OUT
echo "cp /tmp/$MAP_FILE_NAME_WITHOUT_EXTENTION.png $WEB_DIRECTORY/." >>$LOG_OUT
cp "/tmp/$MAP_FILE_NAME_WITHOUT_EXTENTION.png" "$WEB_DIRECTORY/." >>$LOG_OUT 2>>$LOG_OUT
#
echo "finish" >>$LOG_OUT 2>> $LOG_OUT
#
# return map number
#
exit 0
