/* SQL DDL: Create an implementation of the model using the SQL Data Definition Language */
/*  Note: You may want to change some field types to improve the implementation on your DBMS */
/*   Comments such as this may not be supported by your system and may have to be removed *//*   PostgreSQL: You should create the entire database as Unicode!  */



/*=== Table: ProjectDefinition ===*/
/* Definitions of named projects, used e.g. in Diversity References as project markers. */
  /*   ProjectCode: A short name of the project, preferably a single word. This name should later NOT be changed, since it used elswhere. Compare ProjectTitle! */
  /*   ProjectTitle: A short title for the project that can be changed at any time. */
  /*   ProjectDescription: A short text, describing the purpose and scope of the project. */
  /*   ProjectNotes: Internal notes regarding the project, not published on the web. */
  /*   WorkingGroup: The name of the working group or subproject primarily responsible for this project. */
  /*   ProjectEditors: List of editors, refers to the ReferenceTitle data collection in the database. */
  /*   ProjectCopyright: Copyright statement for the data collected for and revised by this project. */
  /*   ProjectVersion: Version number (refers to the database content of this project, not to application development). */
CREATE TABLE "ProjectDefinition"
 ( 
    "ProjectCode"  	 varchar( 25 )     	 NOT NULL UNIQUE,
    "ProjectTitle"  	 varchar( 255 )     	 NOT NULL UNIQUE,
    "ProjectDescription"  	 text              	 NULL,
    "ProjectNotes"  	 text              	 NULL,
    "WorkingGroup"  	 varchar( 255 )     	 NULL,
    "ProjectEditors"  	 varchar( 255 )     	 NULL,
    "ProjectCopyright"  	 varchar( 255 )     	 NULL,
    "ProjectVersion"  	 varchar( 255 )     	 NULL
 );




/*=== Table: UserInfo ===*/
/*  */
  /*   UserAbbrev: An abbreviated short name for the user; this name can be used as an alternative to the full name during data entry (the abbrev. must be unique!). */
  /*   UserName: Name of the user as it will be entered in the related database modules ('last name, first names'; must be unique -> add city in '()' if necessary). */
  /*   UserTitle: Academic title (e.g. 'Prof. Dr.'). */
  /*   WorkingGroup: The name of the working group or subproject a user works for. */
  /*   Function: Function of the user: 1=database manager; 2=scientist; 3=data entry/technical staff; 4=other, as specied in Notes. */
  /*   Organization: If applicable, the university or research institution the user works for. */
  /*   Address: Parts of the address before the city, esp. street or post box. */
  /*   AddressCity: At least the city in which the user works. This part is required, the other parts of the address are optional. */
  /*   AddressCountry: The country or political state part of the user's address. */
  /*   Telephone: Preferred phone number, including area code. */
  /*   Telefax: Preferred fax number, including area code. */
  /*   Email: Email address of the user. */
  /*   Homepage: A link to a web homepage of the user (optional). */
  /*   PrivateTel: One or several private telephone numbers (enter only after written consent of user). */
  /*   PrivateAddress: Private address (enter only after written consent of user). */
  /*   PrivateEmail: Private email address (enter only after written consent of user). */
  /*   Notes: Internal notes. */
  /*   UserPassword: System password to access web server, e.g. for upload or restricted access. */
  /*   AdminUser: System permission to administrate users or operators (= DiversityUsers, this subsystem). */
  /*   AdminMenu: System permission to administrate the web menu structure. */
  /*   UseUpload: System permission to upload files to the web server. */
  /*   UseProjectArea: System permission to reach the project area on the webserver, should be set to yes for all project members. */
  /*   UseRestricted: System permission to enter the restricted area on the web server, this right may be granted also to non-project members. */
  /*   UserCreated_Date: The date and time this user was created. */
  /*   UserDeleted_Date: The date and time this user was deleted. */
  /*   UserDeleted: Set to true if the user is no longer a valid user. */
  /*   CollectionRetrievalPrefs: DiversityCollection: User specific retrieval (query) preferences. */
  /*   CollectionEditPrefs: DiversityCollection: User specific data editing preferences. */
  /*   CollectionImportPrefs: DiversityCollection: User specific data importing preferences. */
  /*   CollectionExportPrefs: DiversityCollection: User specific data exporting preferences. */
  /*   CollectionDefaultValues: DiversityCollection: User specific default values for new records. */
  /*   CollectionPermissions: permissions as: r= read, u= update, i=insert, d=delete. Example: "rui" = read/write, but don't delete. */
  /*   ReferencesRetrievalPrefs: DiversityReferences: User specific retrieval (query) preferences. */
  /*   ReferencesEditPrefs: DiversityReferences: User specific data editing preferences. */
  /*   ReferencesImportPrefs: DiversityReferences: User specific data importing preferences. */
  /*   ReferencesExportPrefs: DiversityReferences: User specific data exporting preferences. */
  /*   ReferencesDefaultValues: DiversityReferences: User specific default values for new records. */
  /*   ReferencesPermissions: permissions as: r= read, u= update, i=insert, d=delete. Example: "rui" = read/write, but don't delete. */
  /*   TaxonomyRetrievalPrefs: DiversityTaxonomy: User specific retrieval (query) preferences. */
  /*   TaxonomyEditPrefs: DiversityTaxonomy: User specific data editing preferences. */
  /*   TaxonomyImportPrefs: DiversityTaxonomy: User specific data importing preferences. */
  /*   TaxonomyExportPrefs: DiversityTaxonomy: User specific data exporting preferences. */
  /*   TaxonomyDefaultValues: DiversityTaxonomy: User specific default values for new records. */
  /*   TaxonomyPermissions: permissions as: r= read, u= update, i=insert, d=delete. Example: "rui" = read/write, but don't delete. */
  /*   DescriptionsRetrievalPrefs: DiversityIdentify: User specific retrieval (query) preferences. */
  /*   DescriptionsEditPrefs: DiversityDescriptions: User specific data editing preferences. */
  /*   DescriptionsImportPrefs: DiversityDescriptions: User specific data importing preferences. */
  /*   DescriptionsExportPrefs: DiversityDescriptions: User specific data exporting preferences. */
  /*   DescriptionsDefaultValues: DiversityDescriptions: User specific default values for new records. */
  /*   DescriptionsPermissions: permissions as: r= read, u= update, i=insert, d=delete. Example: "rui" = read/write, but don't delete. */
CREATE TABLE "UserInfo"
 ( 
    "UserAbbrev"  	 varchar( 20 )     	 NOT NULL UNIQUE,
    "UserName"  	 varchar( 50 )     	 NOT NULL PRIMARY KEY,
    "UserTitle"  	 varchar( 30 )     	 NULL,
    "WorkingGroup"  	 varchar( 50 )     	 NULL,
    "Function"  	 int4              	 NOT NULL DEFAULT 3,
    "Organization"  	 varchar( 255 )     	 NULL,
    "Address"  	 varchar( 255 )     	 NULL,
    "AddressCity"  	 varchar( 255 )     	 NOT NULL,
    "AddressCountry"  	 varchar( 255 )     	 NULL,
    "Telephone"  	 varchar( 255 )     	 NULL,
    "Telefax"  	 varchar( 255 )     	 NULL,
    "Email"  	 varchar( 255 )     	 NULL,
    "Homepage"  	 text              	 NULL,
    "PrivateTel"  	 varchar( 255 )     	 NULL,
    "PrivateAddress"  	 varchar( 255 )     	 NULL,
    "PrivateEmail"  	 varchar( 255 )     	 NULL,
    "Notes"  	 text              	 NULL,
    "UserPassword"  	 varchar( 255 )     	 NOT NULL,
    "AdminUser"  	 bool              	 NOT NULL DEFAULT 'false',
    "AdminMenu"  	 bool              	 NOT NULL DEFAULT 'false',
    "UseUpload"  	 bool              	 NOT NULL DEFAULT 'true',	-- Yes,
    "UseProjectArea"  	 bool              	 NOT NULL DEFAULT 'true',	-- Yes,
    "UseRestricted"  	 bool              	 NOT NULL DEFAULT 'true',	-- Yes,
    "UserCreated_Date"  	 timestamp         	 NULL DEFAULT current_timestamp,
    "UserDeleted_Date"  	 timestamp         	 NULL,
    "UserDeleted"  	 bool              	 NOT NULL DEFAULT 'false',	-- No,
    "CollectionRetrievalPrefs"  	 text              	 NULL,
    "CollectionEditPrefs"  	 text              	 NULL,
    "CollectionImportPrefs"  	 text              	 NULL,
    "CollectionExportPrefs"  	 text              	 NULL,
    "CollectionDefaultValues"  	 text              	 NULL,
    "CollectionPermissions"  	 varchar( 4 )     	 NULL,
    "ReferencesRetrievalPrefs"  	 text              	 NULL,
    "ReferencesEditPrefs"  	 text              	 NULL,
    "ReferencesImportPrefs"  	 text              	 NULL,
    "ReferencesExportPrefs"  	 text              	 NULL,
    "ReferencesDefaultValues"  	 text              	 NULL,
    "ReferencesPermissions"  	 varchar( 4 )     	 NULL,
    "TaxonomyRetrievalPrefs"  	 text              	 NULL,
    "TaxonomyEditPrefs"  	 text              	 NULL,
    "TaxonomyImportPrefs"  	 text              	 NULL,
    "TaxonomyExportPrefs"  	 text              	 NULL,
    "TaxonomyDefaultValues"  	 text              	 NULL,
    "TaxonomyPermissions"  	 varchar( 4 )     	 NULL,
    "DescriptionsRetrievalPrefs"  	 text              	 NULL,
    "DescriptionsEditPrefs"  	 text              	 NULL,
    "DescriptionsImportPrefs"  	 text              	 NULL,
    "DescriptionsExportPrefs"  	 text              	 NULL,
    "DescriptionsDefaultValues"  	 text              	 NULL,
    "DescriptionsPermissions"  	 varchar( 4 )     	 NULL
 );




/*=== Table: UserInfo_Bak ===*/
/*  */
CREATE TABLE "UserInfo_Bak"
 ( 
    "UserAbbrev"  	 varchar( 20 )     	 NULL,
    "UserName"  	 varchar( 50 )     	 NULL,
    "UserTitle"  	 varchar( 30 )     	 NULL,
    "WorkingGroup"  	 varchar( 50 )     	 NULL,
    "Function"  	 int4              	 NULL,
    "Organization"  	 varchar( 255 )     	 NULL,
    "Address"  	 varchar( 255 )     	 NULL,
    "AddressCity"  	 varchar( 255 )     	 NOT NULL,
    "AddressCountry"  	 varchar( 255 )     	 NULL,
    "Telephone"  	 varchar( 255 )     	 NULL,
    "Telefax"  	 varchar( 255 )     	 NULL,
    "Email"  	 varchar( 255 )     	 NULL,
    "Homepage"  	 text              	 NULL,
    "PrivateTel"  	 varchar( 255 )     	 NULL,
    "PrivateAddress"  	 varchar( 255 )     	 NULL,
    "PrivateEmail"  	 varchar( 255 )     	 NULL,
    "Notes"  	 text              	 NULL,
    "UserCreated_Date"  	 timestamp         	 NULL,
    "UserDeleted_Date"  	 timestamp         	 NULL
 );


